@@ -2,7 +2,7 @@ import re
 import textwrap
 
 
-def justify_text(_text, w, align, fill=" "):
+def justify_text(_text, w, align="left", fill=" "):
     wrapper = textwrap.TextWrapper(width=w)
     dedented_text = textwrap.dedent(text=_text)
     txt = wrapper.fill(text=dedented_text)
@@ -30,9 +30,3 @@ def justify_text(_text, w, align, fill=" "):
             _justify_res += justify_both(l, w)+"\n"
 
     return _justify_res
-
-
-sample_text = """Accuracy of geolocation database varies depending on which database you use. For IP-to-country database, some vendors claim to offer 98% to 99% accuracy although typical Ip2Country database accuracy is more like 95%. For IP-to-Region (or City), accuracy range anywhere from 50% to 75% if neighboring cities are treated as correct. Considering that there is no official source of IP-to-Region information, 50+% accuracy is pretty good."""
-width = 40
-align = "center"
-print(justify_text(sample_text, width, align))
